@@ -1,11 +1,11 @@
 package Org::Document;
 
-our $DATE = '2016-12-24'; # DATE
-our $VERSION = '0.53'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.54'; # VERSION
 
 use 5.010;
 use locale;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 use Moo;
 use experimental 'smartmatch';
 no if $] >= 5.021_006, warnings => "locale";
@@ -181,7 +181,7 @@ sub BUILD {
 # parse blocky elements: setting, blocks, headline, drawer
 sub _parse {
     my ($self, $str, $pass) = @_;
-    $log->tracef('-> _parse(%s, pass=%d)', $str, $pass);
+    log_trace('-> _parse(%s, pass=%d)', $str, $pass);
     my $t0 = [gettimeofday];
 
     my $last_el;
@@ -439,7 +439,7 @@ sub _parse {
     }
     @text = ();
 
-    $log->tracef('<- _parse(), elapsed time=%.3fs',
+    log_trace('<- _parse(), elapsed time=%.3fs',
                  tv_interval($t0, [gettimeofday]));
 }
 
@@ -805,7 +805,7 @@ Org::Document - Represent an Org document
 
 =head1 VERSION
 
-This document describes version 0.53 of Org::Document (from Perl distribution Org-Parser), released on 2016-12-24.
+This document describes version 0.54 of Org::Document (from Perl distribution Org-Parser), released on 2017-07-10.
 
 =head1 SYNOPSIS
 
@@ -900,7 +900,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-Parser
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Org-Parser>.
+Source repository is at L<https://github.com/perlancar/perl-Org-Parser>.
 
 =head1 BUGS
 
@@ -916,7 +916,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
