@@ -1,11 +1,11 @@
 package Org::Element::Headline;
 
-our $DATE = '2016-12-24'; # DATE
-our $VERSION = '0.53'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.54'; # VERSION
 
 use 5.010;
 use locale;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 use Moo;
 use experimental 'smartmatch';
 extends 'Org::Element';
@@ -207,7 +207,7 @@ sub get_drawer {
 	my $wanted_drawer_name = shift || "PROPERTIES";
 
 	for my $d (@{$self->children||[]}) {
-        $log->tracef("seeking $wanted_drawer_name drawer in child: %s (%s)", $d->as_string, ref($d));
+        log_trace("seeking $wanted_drawer_name drawer in child: %s (%s)", $d->as_string, ref($d));
 		next unless ($d->isa('Org::Element::Drawer')
 					 && $d->name eq $wanted_drawer_name
 					 && $d->properties);
@@ -235,7 +235,7 @@ sub get_property {
     }
 
     if ($search_docprop // 1) {
-        $log->tracef("Getting property from document's .properties");
+        log_trace("Getting property from document's .properties");
         return $self->document->properties->{$name};
     }
     undef;
@@ -302,7 +302,7 @@ Org::Element::Headline - Represent Org headline
 
 =head1 VERSION
 
-This document describes version 0.53 of Org::Element::Headline (from Perl distribution Org-Parser), released on 2016-12-24.
+This document describes version 0.54 of Org::Element::Headline (from Perl distribution Org-Parser), released on 2017-07-10.
 
 =head1 DESCRIPTION
 
@@ -445,7 +445,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-Parser
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Org-Parser>.
+Source repository is at L<https://github.com/perlancar/perl-Org-Parser>.
 
 =head1 BUGS
 
@@ -461,7 +461,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
