@@ -1,11 +1,11 @@
 package Org::Element::Table;
 
-our $DATE = '2016-12-24'; # DATE
-our $VERSION = '0.53'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.54'; # VERSION
 
 use 5.010;
 use locale;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 use Moo;
 extends 'Org::Element';
 with 'Org::Element::Role';
@@ -32,7 +32,7 @@ sub BUILD {
         my @rows0 = split /\R/, $_str;
         $self->children([]);
         for my $row0 (@rows0) {
-            $log->tracef("table line: %s", $row0);
+            log_trace("table line: %s", $row0);
             next unless $row0 =~ /\S/;
             my $row;
             if ($row0 =~ /^\s*\|--+(?:\+--+)*\|?\s*$/) {
@@ -123,7 +123,7 @@ Org::Element::Table - Represent Org table
 
 =head1 VERSION
 
-This document describes version 0.53 of Org::Element::Table (from Perl distribution Org-Parser), released on 2016-12-24.
+This document describes version 0.54 of Org::Element::Table (from Perl distribution Org-Parser), released on 2017-07-10.
 
 =head1 DESCRIPTION
 
@@ -160,7 +160,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-Parser
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Org-Parser>.
+Source repository is at L<https://github.com/perlancar/perl-Org-Parser>.
 
 =head1 BUGS
 
@@ -176,7 +176,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
